%global	_hardened_build 1
%global	username guacd

Name:           guacd
Version:        0.7.0
Release:        7%{?dist}
Summary:        Proxy daemon for Guacamole
Group:          System Environment/Daemons
License:        MPLv1.1 or GPLv2+ or LGPLv2+
URL:            http://guac-dev.org/
Source0:        http://guac-dev.org/pub/dist/source/%{name}-%{version}.tar.gz
Source1:        %{name}.sysconfig
Source2:        %{name}.service
Source3:        %{name}.init

BuildRequires:  cairo-devel
BuildRequires:  libguac-devel >= %{version}

%if 0%{?fedora} || 0%{?rhel} >= 7
BuildRequires:          systemd-units
%endif

%if 0%{?fedora} == 17
Requires(post):         systemd-units
Requires(preun):        systemd-units
Requires(postun):       systemd-units
%endif

%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7
Requires(post):         systemd-sysv
Requires(post):         systemd
Requires(preun):        systemd
Requires(postun):       systemd
%endif

%if 0%{?rhel} == 6
Requires(post):         /sbin/chkconfig
Requires(preun):        /sbin/chkconfig
Requires(preun):        /sbin/service
Requires(postun):       /sbin/service
%endif

Requires(pre):          shadow-utils

%description
Guacamole is an HTML5 web application that provides access to desktop
environments using remote desktop protocols such as VNC or RDP. A centralized
server acts as a tunnel and proxy, allowing access to multiple desktops through
a web browser. No plugins are needed: the client requires nothing more than a
web browser supporting HTML5 and AJAX.

%{name} is the Guacamole proxy daemon used by the Guacamole web application and
framework to translates between arbitrary protocols and the Guacamole protocol.


%prep
%setup -q


%build
%configure
make %{?_smp_mflags} CFLAGS="%{optflags}"


%install
make install DESTDIR=%{buildroot} INSTALL="install -p"
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}

%if 0%{?fedora} >= 16 || 0%{?rhel} >= 7

# Systemd unit files
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 -D %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

%else

# Initscripts
mkdir -p %{buildroot}%{_initrddir}
install -p -m 755 -D %{SOURCE3} %{buildroot}%{_initrddir}/%{name}

%endif


%pre
getent group %username >/dev/null || groupadd -r %username &>/dev/null || :
getent passwd %username >/dev/null || useradd -r -s /sbin/nologin \
    -d %{_sharedstatedir}/guacd -M -c 'Guacamole proxy daemon' -g %username %username &>/dev/null || :
exit 0

%if 0%{?fedora} == 16 || 0%{?fedora} == 17

%post
if [ $1 -eq 1 ] ; then
    # Initial installation
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable %{name}.service > /dev/null 2>&1 || :
    /bin/systemctl stop %{name}.service > /dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart %{name}.service >/dev/null 2>&1 || :
fi

%endif

%if 0%{?fedora} >= 18 || 0%{?rhel} >= 7

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%endif

%if 0%{?rhel} == 6

%post
/sbin/chkconfig --add %{name}

%preun
if [ "$1" = 0 ]; then
        /sbin/service %{name} stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del %{name}
fi

%postun
if [ "$1" -ge "1" ]; then
        /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi

%endif

%files
%doc AUTHORS LICENSE README
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_mandir}/man8/%{name}.8.*
%{_sbindir}/%{name}
%if 0%{?fedora} >= 16 || 0%{?rhel} >= 7
%{_unitdir}/%{name}.service
%else
%{_initrddir}/%{name}
%endif
%attr(750,%{username},%{username}) %{_sharedstatedir}/%{name}

%changelog
* Wed Jun 19 2013 Simone Caronni <negativo17@gmail.com> - 0.7.0-7
- Revert back license, licensecheck checks only license headers.

* Wed Jun 12 2013 Simone Caronni <negativo17@gmail.com> - 0.7.0-6
- Fix license.

* Sat May 11 2013 Simone Caronni <negativo17@gmail.com> - 0.7.0-5
- Kill daemon by pid on EPEL.
- Change restart policy in service files and fix service dependencies.
- Enable hardened build (#955220).

* Mon Mar 25 2013 Simone Caronni <negativo17@gmail.com> - 0.7.0-4
- Source rebuilt upstream due to bug: http://guac-dev.org/trac/ticket/298

* Wed Jan 30 2013 Simone Caronni <negativo17@gmail.com> - 0.7.0-3
- User creations is for all supported distributions.

* Wed Jan 30 2013 Simone Caronni <negativo17@gmail.com> - 0.7.0-2
- Updated init script according to Fedora template.
  https://fedoraproject.org/wiki/Packaging:SysVInitScript?rd=Packaging/SysVInitScript
- Run daemon as guacd user/group.
- Make sure $HOME is set before starting the daemon or the child crashes.

* Thu Dec 13 2012 Simone Caronni <negativo17@gmail.com> - 0.7.0-1
- Updated to 0.7.0.

* Mon Oct 22 2012 Simone Caronni <negativo17@gmail.com> - 0.6.2-1
- Updated to 0.6.2.

* Wed Oct 17 2012 Simone Caronni <negativo17@gmail.com> - 0.6.1-4
- Fix fedpkg checks. Requires fedpkg > 1.10:
  http://git.fedorahosted.org/cgit/fedpkg.git/commit/?id=11c46c06a3c9cc2f58d68aea964dd37dc028e349
- Change systemd requirements as per new package guidelines.

* Thu Sep 13 2012 Simone Caronni <negativo17@gmail.com> - 0.6.1-3
- Change Source0 URL

* Wed Sep 05 2012 Simone Caronni <negativo17@gmail.com> - 0.6.1-2
- Add Fedora 18 systemd macros.

* Thu Aug 30 2012 Simone Caronni <negativo17@gmail.com> - 0.6.1-1
- Updated to 0.6.1.
- Add Documentation tag to service file.
- Add new foreground option for daemon into service file.

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun 15 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-7
- Removed _isaed build requirements.

* Tue May 29 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-6
- Fix changelog.

* Tue May 29 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-5
- Move systemd-units BR to proper place.
 
* Mon May 28 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-4
- Fixed wrong permissions on systemd service files.
- Small spec fixes.

* Mon May 28 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-3
- Re-added BR on systemd-units.

* Mon May 28 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-2
- Used common macro styles (buildroot, name).
- Removed macros for base commands as per package guidelines.
- Added missing BuildRequires.
- Removed compression for manpages.

* Thu May 10 2012 Simone Caronni <negativo17@gmail.com> - 0.6.0-1
- First build.
